# Correios Webservice Lib
[![Build Status](https://travis-ci.org/trocafone/correios-lib.svg?branch=master)](https://travis-ci.org/trocafone/correios-lib)
[![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/trocafone/correios-lib/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/trocafone/correios-lib/?branch=master)
[![Code Coverage](https://scrutinizer-ci.com/g/trocafone/correios-lib/badges/coverage.png?b=master)](https://scrutinizer-ci.com/g/trocafone/correios-lib/?branch=master)
[![License](https://img.shields.io/badge/licence-MIT-blue.svg)]()

An easy to use and well tested library to use correios webservices.

## Inplemented methods

This project was developed mainly to for reversal logistics, but feel free to colaborate with any improvement you need, the implemented methods are:

#### Logística Reversa ([DOCS](https://github.com/trocafone/correios-lib/blob/master/manuals/Manual de Implementacao do Web Service Logistica Reversa _12_05_2016_Final.pdf)):

- [x] solicitarPostagemReversa
- [x] acompanharPedido
- [x] acompanharPedidoPorData
- [x] cancelarPedido
- [x] calcularDigitoVerificador
- [x] solicitarPostagemSimultanea
- [x] solicitarRange

## Roadmap

Check out the next webservices to be implemented at our [wiki page]()

## Contributing

You can find more about it at the [wiki]()

## Thanks to ...

This project was possible thanks to  these really helpfull projects:

- [Python Zeep](http://docs.python-zeep.org/en/latest/)
- [Certifi](https://certifi.io/en/latest/)
- [voluptuous](https://github.com/alecthomas/voluptuous)
- [Brazilnum](https://github.com/poliquin/brazilnum)
